@@ -2,12 +2,16 @@
  *
  * This header provedes class definition for errors thrown by my functions
  * such that thay can be catched and solved without aborting R.
+ *
+ *    REVISION 1:   20/12/2011
+ *                  exception, sstream, iostream tried to be replaced by R 'error' function
  */
 
 
 #ifndef AK_ERROR_H
 #define AK_ERROR_H
 
+#include <R_ext/Print.h>
 #include <exception>
 #include <string>
 #include <sstream>
@@ -24,15 +28,17 @@
       returnR (std::string & sterr, const int err)
                : fout_ (err)
       {
-        std::cerr << sterr << std::endl;
-        std::cerr << std::endl;
+        //std::cerr << sterr << std::endl;
+        //std::cerr << std::endl;
+        REprintf("%s\n\n", (char*)(&sterr));
       }
 
       returnR (const char * sterr, const int err)
 	: fout_ (err)
       { 
-	std::cerr << sterr << std::endl;
-	std::cerr << std::endl;
+	//std::cerr << sterr << std::endl;
+	//std::cerr << std::endl;
+        REprintf("%s\n\n", sterr);
       }
 
       returnR (const int err)
@@ -61,6 +67,3 @@
   };  // end of class returnR
 
 #endif
-
-
-
