@@ -17,6 +17,10 @@ void
 regresRes_GS(double* regResid,  const double* YsA,      const BetaGamma* bg,  const double* bA,  
              const double* XA,  const int* nincluster,  const int* nobs,      const int* ncluster);
 
+void
+regresRes_GS2006(double* regResid,  const double* YsA,      const BetaGamma* bg,  const double* bA,  
+                 const double* XA,  const int* nincluster,  const int* nobs,      const int* ncluster);
+
 void
 linPred_GS(double* linPred,   const BetaGamma* bg,    const double* bA,  
            const double* XA,  const int* nincluster,  const int* nobs,      const int* ncluster);
